==> dxl-bootstrap-0.1.0.tgz: package/README.md <==
# OpenDXL Bootstrap JavaScript Library
[![Latest NPM Version](https://img.shields.io/npm/v/@opendxl/dxl-bootstrap.svg)](https://www.npmjs.com/package/@opendxl/dxl-bootstrap)
[![Build Status](https://img.shields.io/travis/opendxl/opendxl-bootstrap-javascript/master.svg)](https://travis-ci.org/opendxl/opendxl-bootstrap-javascript)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

## Overview

The OpenDXL Bootstrap JavaScript library includes helpers for developing a
[Data Exchange Layer](http://www.mcafee.com/us/solutions/data-exchange-layer.aspx)
integration with JavaScript. The helpers extend the basic functionality of the
[OpenDXL JavaScript Client (Node.js)](https://github.com/opendxl/opendxl-client-javascript).

## Documentation

See the [Wiki](https://github.com/opendxl/opendxl-bootstrap-javascript/wiki)
for an overview of the OpenDXL Bootstrap JavaScript library.

See the
[OpenDXL Bootstrap JavaScript SDK Documentation](https://opendxl.github.io/opendxl-bootstrap-javascript/jsdoc)
for API documentation.

## Installation

To start using the OpenDXL Bootstrap JavaScript library:

* Download the [Latest Release](https://github.com/opendxl/opendxl-bootstrap-javascript/releases/latest)
* Extract the release .zip file
* View the `README.html` file located at the root of the extracted files.
  * The `README` links to the SDK documentation which includes installation instructions, API details, and samples.
  * The SDK documentation is also available on-line [here](https://opendxl.github.io/opendxl-bootstrap-javascript/jsdoc).

## Bugs and Feedback

For bugs, questions and discussions please use the
[GitHub Issues](https://github.com/opendxl/opendxl-bootstrap-javascript/issues).

## LICENSE

Copyright 2018 McAfee, LLC

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

==> dxl-bootstrap-0.1.1.tgz: package/README.md <==
# OpenDXL Bootstrap JavaScript Library
[![Latest NPM Version](https://img.shields.io/npm/v/@opendxl/dxl-bootstrap.svg)](https://www.npmjs.com/package/@opendxl/dxl-bootstrap)
[![Actions Status](https://github.com/opendxl/opendxl-bootstrap-javascript/workflows/Build/badge.svg)](https://github.com/opendxl/opendxl-bootstrap-javascript/actions)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

## Overview

The OpenDXL Bootstrap JavaScript library includes helpers for developing a
[Data Exchange Layer](https://www.trellix.com/assets/docs/data-sheets/trellix-dataexchangelayer-datasheet.pdf)
integration with JavaScript. The helpers extend the basic functionality of the
[OpenDXL JavaScript Client (Node.js)](https://github.com/opendxl/opendxl-client-javascript).

## Documentation

See the [Wiki](https://github.com/opendxl/opendxl-bootstrap-javascript/wiki)
for an overview of the OpenDXL Bootstrap JavaScript library.

See the
[OpenDXL Bootstrap JavaScript SDK Documentation](https://opendxl.github.io/opendxl-bootstrap-javascript/jsdoc)
for API documentation.

## Installation

To start using the OpenDXL Bootstrap JavaScript library:

* Download the [Latest Release](https://github.com/opendxl/opendxl-bootstrap-javascript/releases/latest)
* Extract the release .zip file
* View the `README.html` file located at the root of the extracted files.
  * The `README` links to the SDK documentation which includes installation instructions, API details, and samples.
  * The SDK documentation is also available on-line [here](https://opendxl.github.io/opendxl-bootstrap-javascript/jsdoc).

## Bugs and Feedback

For bugs, questions and discussions please use the
[GitHub Issues](https://github.com/opendxl/opendxl-bootstrap-javascript/issues).

## LICENSE

Copyright 2024 Musarubra US LLC

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
